@@ -6,8 +6,8 @@
 ;; Homepage: https://github.com/emacscollective/borg
 ;; Keywords: tools
 
-;; Package-Version: 4.4.0
-;; Package-Revision: v4.4.0-0-g61f9e083b8d9
+;; Package-Version: 4.4.1
+;; Package-Revision: v4.4.1-0-g99933c616380
 ;; Package-Requires: (
 ;;     (emacs "28.1")
 ;;     (epkg   "4.1")
@@ -524,6 +524,9 @@ exists."
   (when noninteractive
     (borg--load-config "etc/borg/init.el"))
   (info-initialize)
+  (let ((dir (car (Info-default-dirs))))
+    (when (file-directory-p dir)
+      (cl-pushnew dir Info-directory-list :test #'file-equal-p)))
   (let ((start (current-time))
         (skipped 0)
         (initialized 0))
